@@ -8,7 +8,7 @@ import matplotlib.image as mpimg
 import matplotlib.pyplot as plt
 import numpy as np
 from scipy.optimize import curve_fit
-from skimage.color import rgb2gray
+# from skimage.color import rgb2gray
 import codecs
 import dill
 
@@ -679,10 +679,19 @@ def reshape_img(img, ix, iy, lm):
     *Returns
         * The reshaped picture as an array
     """
-    ix = int(ix)
-    iy = int(iy)
-    ix_r = np.arange(ix - lm, ix + lm)
-    iy_r = np.arange(iy - lm, iy + lm)
+    ix, iy, lm = int(ix), int(iy), int(lm)
+    max_x, max_y = len(img.T), len(img)
+    min_x, min_y = 0, 0
+    if ix - lm > 0:
+        min_x = ix - lm
+    if iy - lm > 0:
+        min_y = iy - lm
+    if ix + lm < max_x:
+        max_x = ix + lm
+    if iy + lm < max_y:
+        max_y = iy + lm
+    ix_r = np.arange(min_x, max_x)
+    iy_r = np.arange(min_y, max_y)
     img = img[iy_r]
     img = img.T[ix_r].T
     return img
@@ -697,7 +706,7 @@ def import_image(fname, reshape=[]):
     * Returns
         * the picture as 2D array
     """
-    file_format = ["tif", "jpg", "jpeg", "png", "asc", "bmp"]
+    file_format = ["tif", "jpg", "jpeg", "asc", "png", "bmp"]
     ext = fname.split('.')[len(fname.split('.')) - 1]
     ext = ext.lower()
     if not (ext in file_format):
@@ -708,7 +717,7 @@ def import_image(fname, reshape=[]):
             img = np.array([[float(x) for x in line.split()] for line in ff])
     else:
         img = np.double(mpimg.imread(fname))
-        img = rgb2gray(img)
+        # img = rgb2gray(img)
     if len(reshape) == 3:
         img = reshape_img(img, reshape[0], reshape[1], reshape[2])
 
